/* jshint browser: true */
(function() {
    'use strict';

    // Exit immediately if we're not running in Electron
    if (!window.ELECTRON) {
        return;
    }

    // Reload the page when anything in `dist` changes
    var fs = window.requireNode('fs');
    var path = window.requireNode('path');
    
    /**
     * Watch a given directory for changes and reload
     * on change
     * 
     * @param sub directory
     */
    var watch = function (sub) {
        var dirname = __dirname || path.resolve(path.dirname());
        var isInTest = !!window.QUnit;

        if (isInTest) {
          // In tests, __dirname is `<project>/tmp/<broccoli-dist-path>/tests`.
          // In normal `ember:electron` it's `<project>/dist`.
          // To achieve the regular behavior in testing, go to parent dir, which contains `tests` and `assets`
          dirname = path.join(dirname, '..');
        }

        if (sub) {
          dirname = path.join(dirname, sub);
        }

        fs.watch(dirname, {recursive: true}, function (e) {
            window.location.reload();
        });
    };
    
    /**
     * Install Devtron in the current window.
     */
    var installDevtron = function () {
        var devtron = window.requireNode('devtron');
        
        if (devtron) {
            devtron.install();
        }
    }

    document.addEventListener('DOMContentLoaded', function (e) {
        var dirname = __dirname || path.resolve(path.dirname());

        fs.stat(dirname, function (err, stat) {
            if (!err) {
                watch();

                // On linux, the recursive `watch` command is not fully supported:
                // https://nodejs.org/docs/latest/api/fs.html#fs_fs_watch_filename_options_listener
                //
                // However, the recursive option WILL watch direct children of the
                // given directory.  So, this hack just manually sets up watches on
                // the expected subdirs -- that is, `assets` and `tests`.
                if (process.platform === 'linux') {
                    watch('/assets');
                    watch('/tests');
                }
            }
        });
        
        installDevtron();
    });
})();
